@@ -1349,6 +1349,8 @@ gcm_prefs_get_profile_title (CcColorPanel *prefs, CdProfile *profile)
 
   g_return_val_if_fail (profile != NULL, NULL);
 
+  string = NULL;
+
   /* get properties */
   ret = cd_profile_connect_sync (profile,
                                  priv->cancellable,
@@ -1447,29 +1449,32 @@ static GtkTreeIter *
 get_iter_for_profile (GtkTreeModel *model, CdProfile *profile, GtkTreeIter *parent)
 {
   const gchar *id;
-  GtkTreeIter iter_tmp;
   gboolean ret;
-  GtkTreeIter *iter = NULL;
+  GtkTreeIter iter;
   CdProfile *profile_tmp;
 
   /* get first element */
-  ret = gtk_tree_model_iter_children (model, &iter_tmp, parent);
+  ret = gtk_tree_model_iter_children (model, &iter, parent);
   if (!ret)
-    goto out;
+    return NULL;
 
   /* remove the other elements */
   id = cd_profile_get_id (profile);
-  do
+  while (ret)
     {
-      gtk_tree_model_get (model, &iter_tmp,
+      gtk_tree_model_get (model, &iter,
               GCM_PREFS_COLUMN_PROFILE, &profile_tmp,
               -1);
       if (g_strcmp0 (id, cd_profile_get_id (profile_tmp)) == 0)
-        iter = &iter_tmp;
+        {
+          g_object_unref (profile_tmp);
+          return gtk_tree_iter_copy (&iter);
+        }
       g_object_unref (profile_tmp);
-    } while (iter == NULL && gtk_tree_model_iter_next (model, &iter_tmp));
-out:
-  return iter;
+      ret = gtk_tree_model_iter_next (model, &iter);
+    }
+
+  return NULL;
 }
 
 static void
@@ -1611,12 +1616,9 @@ skip:
       iter_tmp_p = get_iter_for_profile (GTK_TREE_MODEL (priv->list_store_devices),
                                          profile_tmp, iter);
       if (iter_tmp_p == NULL)
-        {
-          gtk_tree_store_append (priv->list_store_devices, &iter_tmp, iter);
-          iter_tmp_p = &iter_tmp;
-        }
+        gtk_tree_store_append (priv->list_store_devices, &iter_tmp, iter);
 
-      gtk_tree_store_set (priv->list_store_devices, iter_tmp_p,
+      gtk_tree_store_set (priv->list_store_devices, iter_tmp_p ? iter_tmp_p : &iter_tmp,
                           GCM_PREFS_COLUMN_DEVICE, device,
                           GCM_PREFS_COLUMN_PROFILE, profile_tmp,
                           GCM_PREFS_COLUMN_DEVICE_PATH, cd_device_get_object_path (device),
@@ -1626,6 +1628,8 @@ skip:
                           GCM_PREFS_COLUMN_RADIO_VISIBLE, TRUE,
                           GCM_PREFS_COLUMN_RADIO_ACTIVE, i==0,
                           -1);
+      if (iter_tmp_p != NULL)
+        gtk_tree_iter_free (iter_tmp_p);
       g_free (title_tmp);
       g_free (sort_tmp);
       g_string_free (date_tmp, TRUE);
@@ -1645,11 +1649,13 @@ out:
 static void
 gcm_prefs_device_changed_cb (CdDevice *device, CcColorPanel *prefs)
 {
+  const gchar *id;
+  gboolean ret;
+  gchar *id_tmp;
   GtkTreeIter iter;
   GtkTreeModel *model;
-  const gchar *id;
-  gchar *id_tmp;
-  gboolean ret;
+  GtkTreeSelection *selection;
+  GtkWidget *widget;
   CcColorPanelPrivate *priv = prefs->priv;
 
   /* get first element */
@@ -1666,7 +1672,15 @@ gcm_prefs_device_changed_cb (CdDevice *device, CcColorPanel *prefs)
                           GCM_PREFS_COLUMN_DEVICE_PATH, &id_tmp,
                           -1);
       if (g_strcmp0 (id_tmp, id) == 0)
-        gcm_prefs_device_set_model_by_iter (prefs, device, &iter);
+        {
+          /* populate device, and then select it */
+          gcm_prefs_device_set_model_by_iter (prefs, device, &iter);
+          widget = GTK_WIDGET (gtk_builder_get_object (priv->builder,
+                                                       "treeview_devices"));
+          selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (widget));
+          gtk_tree_selection_select_iter (selection, &iter);
+
+        }
       g_free (id_tmp);
     } while (gtk_tree_model_iter_next (model, &iter));
 }
