@@ -245,6 +245,7 @@ on_cups_notification (GDBusConnection *connection,
   if (g_strcmp0 (signal_name, "PrinterAdded") != 0 &&
       g_strcmp0 (signal_name, "PrinterDeleted") != 0 &&
       g_strcmp0 (signal_name, "PrinterStateChanged") != 0 &&
+      g_strcmp0 (signal_name, "PrinterStopped") != 0 &&
       g_strcmp0 (signal_name, "JobCreated") != 0 &&
       g_strcmp0 (signal_name, "JobCompleted") != 0)
     return;
@@ -279,7 +280,8 @@ on_cups_notification (GDBusConnection *connection,
 
   if (g_strcmp0 (signal_name, "PrinterAdded") == 0 ||
       g_strcmp0 (signal_name, "PrinterDeleted") == 0 ||
-      g_strcmp0 (signal_name, "PrinterStateChanged") == 0)
+      g_strcmp0 (signal_name, "PrinterStateChanged") == 0 ||
+      g_strcmp0 (signal_name, "PrinterStopped") == 0)
     actualize_printers_list (self);
   else if (g_strcmp0 (signal_name, "JobCreated") == 0 ||
            g_strcmp0 (signal_name, "JobCompleted") == 0)
@@ -292,12 +294,14 @@ on_cups_notification (GDBusConnection *connection,
       if ((http = httpConnectEncrypt (cupsServer (), ippPort (),
                                      cupsEncryption ())) != NULL)
         {
-          request = ippNewRequest(IPP_GET_JOB_ATTRIBUTES);
-          ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_URI,
+          request = ippNewRequest (IPP_GET_JOB_ATTRIBUTES);
+          ippAddString (request, IPP_TAG_OPERATION, IPP_TAG_URI,
                        "job-uri", NULL, job_uri);
+          ippAddString (request, IPP_TAG_OPERATION, IPP_TAG_NAME,
+                        "requesting-user-name", NULL, cupsUser ());
           ippAddStrings (request, IPP_TAG_OPERATION, IPP_TAG_KEYWORD,
                          "requested-attributes", G_N_ELEMENTS (requested_attrs), NULL, requested_attrs);
-          response = cupsDoRequest(http, request, "/");
+          response = cupsDoRequest (http, request, "/");
 
           if (response)
             {
@@ -334,6 +338,7 @@ renew_subscription (gpointer data)
   static const char * const events[] = {
           "printer-added",
           "printer-deleted",
+          "printer-stopped",
           "printer-state-changed",
           "job-created",
           "job-completed"};
